/*
 * Enhydra Java Application Server Project
 * 
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See 
 * the License for the specific terms governing rights and limitations
 * under the License.
 * 
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 * 
 * Contributor(s):
 * 
 * $Id: edir_debug.h,v 1.1.2.3.2.1 2000/10/19 17:59:07 jasona Exp $
 */

#ifndef __EDIR_DEBUG_H__
#define __EDIR_DEBUG_H__ 1
#ifdef __cplusplus
extern "C" {
#endif

/*
 * Function call level debugging
 */
#define EDIR_DEBUG_MASK_FUNCS_IN		(0x00000001)
#define EDIR_DEBUG_MASK_FUNCS_OUT		(0x00000002)
#define EDIR_DEBUG_MASK_STATE_IN		(0x00000004)
#define EDIR_DEBUG_MASK_STATE_OUT		(0x00000008)
#ifdef DEBUG
#define EDIR_DEBUG_FUNCS_IN(P) \
	    if (edir_debug & EDIR_DEBUG_MASK_FUNCS_IN) edir_log_debug P ;
#define EDIR_DEBUG_FUNCS_OUT(P) \
	    if (edir_debug & EDIR_DEBUG_MASK_FUNCS_OUT) edir_log_debug P ;
#define EDIR_DEBUG_STATE_IN(P) \
	    if (edir_debug & EDIR_DEBUG_MASK_STATE_IN) edir_log_debug P ;
#define EDIR_DEBUG_STATE_OUT(P) \
	    if (edir_debug & EDIR_DEBUG_MASK_STATE_OUT) edir_log_debug P ;
#else
#define EDIR_DEBUG_FUNCS_IN(P) /* */
#define EDIR_DEBUG_FUNCS_OUT(P) /* */
#define EDIR_DEBUG_STATE_IN(P) /* */
#define EDIR_DEBUG_STATE_OUT(P) /* */
#endif

/*
 * General debugging 
 */
#define EDIR_DEBUG_MASK_SPARSE		(0x00000010)
#define EDIR_DEBUG_MASK_NORMAL		(0x00000020)
#define EDIR_DEBUG_MASK_VERBOSE		(0x00000040)
#define EDIR_DEBUG_MASK_EVERYTHING	(0x00000080)
#ifdef DEBUG
#define EDIR_DEBUG_SPARSE(P) \
	    if (edir_debug & EDIR_DEBUG_MASK_SPARSE) edir_log_debug P ;
#define EDIR_DEBUG_NORMAL(P) \
	    if (edir_debug & EDIR_DEBUG_MASK_NORMAL) edir_log_debug P ;
#define EDIR_DEBUG_VERBOSE(P) \
	    if (edir_debug & EDIR_DEBUG_MASK_VERBOSE) edir_log_debug P ;
#define EDIR_DEBUG_EVERYTHING(P) \
	    if (edir_debug & EDIR_DEBUG_MASK_EVERYTHING) edir_log_debug P ;
#else
#define EDIR_DEBUG_SPARSE(P) /* */
#define EDIR_DEBUG_NORMAL(P) /* */
#define EDIR_DEBUG_VERBOSE(P) /* */
#define EDIR_DEBUG_EVERYTHING(P) /* */
#endif

/*
 * Protocol debugging.
 */
#define EDIR_DEBUG_MASK_SOCK		(0x00000100)
#define EDIR_DEBUG_MASK_SOCK_VERBOSE	(0x00000200)
#define EDIR_DEBUG_MASK_SOCK_SEND	(0x00000400)
#define EDIR_DEBUG_MASK_SOCK_RECV	(0x00000800)
#ifdef DEBUG
#define EDIR_DEBUG_SOCK(P) \
	    if (edir_debug & EDIR_DEBUG_MASK_SOCK) edir_log_debug P ;
#define EDIR_DEBUG_SOCK_VERBOSE(P) \
	    if (edir_debug & EDIR_DEBUG_MASK_SOCK_VERBOSE) edir_log_debug P ;
#define EDIR_DEBUG_SOCK_SEND(P) \
	    if (edir_debug & EDIR_DEBUG_MASK_SOCK_SEND) edir_log_debug P ;
#define EDIR_DEBUG_SOCK_RECV(P) \
	    if (edir_debug & EDIR_DEBUG_MASK_SOCK_RECV) edir_log_debug P ;
#else
#define EDIR_DEBUG_SOCK(P)
#define EDIR_DEBUG_SOCK_VERBOSE(P)
#define EDIR_DEBUG_SOCK_SEND(P)
#define EDIR_DEBUG_SOCK_RECV(P)
#endif

/*
 * Special mask to allow faking of Enhydra Director connection.
 */
#define EDIR_DEBUG_MASK_FAKE_IT		(0x80000000)

#ifdef DEBUG
#define EDIR_IF_DEBUG(STMT)	STMT
#else
#define EDIR_IF_DEBUG(STMT)
#endif

extern int32 edir_debug;
extern int32 edir_debug_level;

#ifdef __cplusplus
} /* Extern "C" */
#endif
#endif /* __EDIR_DEBUG_H__ */

